Crate yellowstone_vixen

Crate yellowstone_vixen 

Vixen provides a simple API for requesting, parsing, and consuming data from Yellowstone.

Re-exports

pub extern crate thiserror;
pub extern crate yellowstone_vixen_core as vixen_core;
pub use handler::Handler;
pub use handler::HandlerResult;
pub use handler::Pipeline;
pub use vixen_core::bs58;
pub use util::*;

Modules

builder
Builder types for the Vixen runtime and stream server.
config
Configuration types for the Vixen runtime.
filter_pipeline
Pipeline equivalent that allows for transaction custom filters
handler
Helper types for bundling Vixen parsers and handler callbacks.
instruction
Helper types for parsing and dispatching instructions from transaction updates.
sources
Sources for Vixen.
util
Utility functions for the Vixen runtime.

Structs

Runtime
The main runtime for Vixen.

Enums

CommitmentLevel
Type mirroring the CommitmentLevel enum in the geyser crate but serializable. Used to avoid need for custom deserialization logic.
Error
An error thrown by the Vixen runtime.